# mtwaffle

![](https://img.shields.io/badge/status-alpha-red.svg)
[![Version](http://img.shields.io/pypi/v/mtwaffle.svg)](https://pypi.python.org/pypi/mtwaffle/)
[![License](http://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/kinverarity1/mtwaffle/blob/master/LICENSE)
[![Python versions](https://img.shields.io/pypi/pyversions/mtwaffle.svg)](https://www.python.org/downloads/)

Assorted functions for processing and interpreting magnetotelluric data.

To install:

```bash
$ pip install mtwaffle
```

Requirements: numpy, scipy, matplotlib

See the [quickstart tutorial](https://github.com/kinverarity1/mtwaffle/blob/master/notebooks/Quickstart%20tutorial.ipynb) Jupyter notebook to get started. There are other tutorials in the [notebooks folder](https://github.com/kinverarity1/mtwaffle/blob/master/notebooks).

